@@ -450,9 +450,16 @@ static bool isAliasDecl(const Decl *TheDecl, const VarDecl *IndexVar) {
       const CXXOperatorCallExpr *OpCall = cast<CXXOperatorCallExpr>(Init);
       if (OpCall->getOperator() == OO_Star)
         return isDereferenceOfOpCall(OpCall, IndexVar);
+      if (OpCall->getOperator() == OO_Subscript) {
+        assert(OpCall->getNumArgs() == 2);
+        return true;
+      }
       break;
   }
 
+  case Stmt::CXXMemberCallExprClass:
+    return true;
+
   default:
     break;
   }
