@@ -10,8 +10,9 @@
 #include "../ClangTidy.h"
 #include "../ClangTidyModule.h"
 #include "../ClangTidyModuleRegistry.h"
+#include "../readability/NamespaceCommentCheck.h"
+#include "HeaderGuardCheck.h"
 #include "IncludeOrderCheck.h"
-#include "NamespaceCommentCheck.h"
 #include "TwineLocalCheck.h"
 
 namespace clang {
@@ -20,14 +21,11 @@ namespace tidy {
 class LLVMModule : public ClangTidyModule {
 public:
   void addCheckFactories(ClangTidyCheckFactories &CheckFactories) override {
-    CheckFactories.addCheckFactory(
-        "llvm-include-order", new ClangTidyCheckFactory<IncludeOrderCheck>());
-    CheckFactories.addCheckFactory(
-        "llvm-namespace-comment",
-        new ClangTidyCheckFactory<NamespaceCommentCheck>());
-    CheckFactories.addCheckFactory(
-        "llvm-twine-local",
-        new ClangTidyCheckFactory<TwineLocalCheck>());
+    CheckFactories.registerCheck<LLVMHeaderGuardCheck>("llvm-header-guard");
+    CheckFactories.registerCheck<IncludeOrderCheck>("llvm-include-order");
+    CheckFactories.registerCheck<readability::NamespaceCommentCheck>(
+        "llvm-namespace-comment");
+    CheckFactories.registerCheck<TwineLocalCheck>("llvm-twine-local");
   }
 };
 
